function [dn,dplen,vdpp,vdpn,emf,rzone,patm,name] = myFanData(verbose)
% myFanData  Manually store flow bench data for a fan curve
%
% Synopsis:  [dn,dplen,dpp,dpn,emf,rt,patm,name] = myFanData
%            [dn,dplen,dpp,dpn,emf,rt,patm,name] = myFanData(verbose)
%
% Input: verbose = (optional) flag to turn printing on/off
%                  Default: verbose = 1 (true), print raw data
%
% Output: dn = nozzle diamter (m)  (can be different for each measurement)
%         dplen = diameter of upstream plenum (m)
%         vdpp = voltage for pressure transducer across the plenum (V)
%         vdpn = voltage for pressure transducer across the nozzle (V)
%         emf = emf for thermocouple upstream of the nozzle (V)
%         rt = resistance of thermistor in the zone box (Ohms)
%         patm = atmospheric pressure in the lab (Pa)
%         name = string used to identify the data set

if nargin<1, verbose=1;  end

% --- Assign values from measurements
name = 'Panaflow FBA12G24M';   %  Label for this data set
rzone = 0.5*(12660+12397);     %  Thermistor measured at start and finish  (Ohms)
patm = 750.32 * 101325/760;    %  Atmospheric pressure measured with barometer (Pa)
dplen = 22*2.54e-2;            %  Upstream plenum diameter

dn = [1.00; 1.00; 1.00; 1.00; 1.00; 1.00; 1.696; 1.696; ...
      1.696; 1.696; 1.696; 1.696] * 2.54e-2;
vdpp = [1.55; 1.82; 2.03; 1.44; 1.45; 1.67; 1.53; 1.15; ...
        1.66; 1.04; 1.27; 1.43];
vdpn = [1.99; 1.285; 1.08; 2.94; 2.83; 1.59; 1.176; 1.60; ...
       1.097; 1.69;  1.50; 1.31];
emf = [0.040; 0.043; 0.046; 0.050; 0.053; 0.053; 0.057; 0.057; ...
       0.056; 0.058; 0.057; 0.0550]*1e-3;  %  convert mV to V

if (verbose)
  % --- Print table of raw data
  fprintf('\nData for %s:\n',name);
  fprintf('\tPlenum diameter      = %12.3e m  (%8.3f inch)\n',dplen,dplen/2.54e-2);
  fprintf('\tZone box thermistor  = %12.3e Ohm\n',rzone);
  fprintf('\tAtmospheric pressure = %12.4e Pa\n',patm);
  fprintf('\n    dn       emf       vdpp      vdpn\n');
  fprintf('   (cm)      (mv)      (V)       (V)\n');
  for i=1:length(dn)
    fprintf('%8.4f  %8.4f  %8.4f  %8.4f\n',dn(i)*100,emf(i)*1000,vdpp(i),vdpn(i));
  end
end